@@ -31,22 +31,23 @@ import string
 from fileutils import abspath
 from settings import global_settings
 from admin import add_path_first, create_missing_folders, create_missing_app_folders
+from globals import current
 
-# this will be uncommented in future versions:
-# from custom_import import custom_import_install
+from custom_import import custom_import_install
+from contrib.simplejson import dumps
 
 #  Remarks:
 #  calling script has inserted path to script directory into sys.path
-#  applications_parent (path to applications/, site-packages/ etc) 
-#  defaults to that directory set sys.path to 
+#  applications_parent (path to applications/, site-packages/ etc)
+#  defaults to that directory set sys.path to
 #  ("", gluon_parent/site-packages, gluon_parent, ...)
 #
 #  this is wrong:
 #  web2py_path = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 #  because we do not want the path to this file which may be Library.zip
-#  gluon_parent is the directory containing gluon, web2py.py, logging.conf 
+#  gluon_parent is the directory containing gluon, web2py.py, logging.conf
 #  and the handlers.
-#  applications_parent (web2py_path) is the directory containing applications/ 
+#  applications_parent (web2py_path) is the directory containing applications/
 #  and routes.py
 #  The two are identical unless web2py_path is changed via the web2py.py -f folder option
 #  main.web2py_path is the same as applications_parent (for backward compatibility)
@@ -61,7 +62,7 @@ web2py_path = global_settings.applications_parent # backward compatibility
 global_settings.app_folders = set()
 global_settings.debugging = False
 
-# custom_import_install(web2py_path)
+custom_import_install(web2py_path)
 
 create_missing_folders()
 
@@ -342,6 +343,7 @@ def wsgibase(environ, responder):
       - file and sub may also contain '-', '=', '.' and '/'
     """
 
+    current.__dict__.clear()
     request = Request()
     response = Response()
     session = Session()
@@ -361,7 +363,8 @@ def wsgibase(environ, responder):
                 # serve file if static
                 # ##################################################
 
-                if not environ.get('PATH_INFO',None) and environ.get('REQUEST_URI',None):
+                if not environ.get('PATH_INFO',None) and \
+                        environ.get('REQUEST_URI',None):
                     # for fcgi, get path_info and query_string from request_uri
                     items = environ['REQUEST_URI'].split('?')
                     environ['PATH_INFO'] = items[0]
@@ -369,6 +372,10 @@ def wsgibase(environ, responder):
                         environ['QUERY_STRING'] = items[1]
                     else:
                         environ['QUERY_STRING'] = ''
+                if not environ.get('HTTP_HOST',None):
+                    environ['HTTP_HOST'] = '%s:%s' % (environ.get('SERVER_NAME'),
+                                                      environ.get('SERVER_PORT'))
+
                 (static_file, environ) = rewrite.url_in(request, environ)
                 if static_file:
                     if request.env.get('query_string', '')[:10] == 'attachment':
@@ -379,15 +386,26 @@ def wsgibase(environ, responder):
                 # fill in request items
                 # ##################################################
 
-                request.client = get_client(request.env)
-                request.folder = abspath('applications', request.application) + os.sep
-                request.ajax = str(request.env.http_x_requested_with).lower() == 'xmlhttprequest'
-                request.cid = request.env.http_web2py_component_element
+                http_host = request.env.http_host.split(':',1)[0]
                 
+                local_hosts = [http_host,'::1','127.0.0.1','::ffff:127.0.0.1']
+                if not global_settings.web2py_runtime_gae:
+                    local_hosts += [socket.gethostname(),
+                                    socket.gethostbyname(http_host)]
+                request.client = get_client(request.env)
+                request.folder = abspath('applications',
+                                         request.application) + os.sep
+                x_req_with = str(request.env.http_x_requested_with).lower()
+                request.ajax = x_req_with == 'xmlhttprequest'
+                request.cid = request.env.http_web2py_component_element
+                request.is_local = request.env.remote_addr in local_hosts
+                request.is_https = request.env.wsgi_url_scheme \
+                    in ['https', 'HTTPS'] or request.env.https == 'on'
+
                 # ##################################################
                 # compute a request.uuid to be used for tickets and toolbar
                 # ##################################################
-                
+
                 response.uuid = request.compute_uuid()
 
                 # ##################################################
@@ -498,12 +516,13 @@ def wsgibase(environ, responder):
                 # ##################################################
 
                 if request.cid:
+
                     if response.flash and not 'web2py-component-flash' in http_response.headers:
                         http_response.headers['web2py-component-flash'] = \
-                            str(response.flash).replace('\n','')
+                            dumps(str(response.flash).replace('\n',''))
                     if response.js and not 'web2py-component-command' in http_response.headers:
                         http_response.headers['web2py-component-command'] = \
-                            str(response.js).replace('\n','')
+                            response.js.replace('\n','')
                 if session._forget:
                     del response.cookies[response.session_id_name]
                 elif session._secure:
