@@ -406,10 +406,7 @@ class TemplateParser(object):
         """
         Raise an error using itself as the filename and textual content.
         """
-        if text:
-            raise restricted.RestrictedError(self.name, text, message)
-        else:
-            raise restricted.RestrictedError(self.name, self.text, message)
+        raise restricted.RestrictedError(self.name, text or self.text, message)
 
     def _get_file_text(self, filename):
         """
@@ -454,7 +451,7 @@ class TemplateParser(object):
                            writer  = self.writer,
                            delimiters = self.delimiters)
 
-        content.append(str(t.content))
+        content.append(t.content)
 
     def extend(self, filename):
         """
