@@ -40,7 +40,7 @@ try:
 except NameError:
     BaseException = Exception
 
-ProgramName = 'web2py Enterprise Web Framework'
+ProgramName = 'web2py Web Framework'
 ProgramAuthor = 'Created by Massimo Di Pierro, Copyright 2007-2011'
 versioninfo = open('VERSION', 'r')
 ProgramVersion = versioninfo.read().strip()
@@ -698,6 +698,12 @@ def console():
                       default=None,
                       help='should be followed by a list of arguments to be passed to script, to be used with -S, -A must be the last option')
 
+    parser.add_option('--no-banner',
+                      action='store_true',
+                      default=False,
+                      dest='nobanner',
+                      help='Do not print header banner')
+
     msg = 'listen on multiple addresses: "ip:port:cert:key;ip2:port2:cert2:key2;..." (:cert:key optional; no spaces)'
     parser.add_option('--interfaces',
                       action='store',
@@ -768,22 +774,24 @@ def start(cron=True):
 
     (options, args) = console()
 
-    print ProgramName
-    print ProgramAuthor
-    print ProgramVersion
+    if not options.nobanner:
+        print ProgramName
+        print ProgramAuthor
+        print ProgramVersion
 
     from dal import drivers
-    print 'Database drivers available: %s' % ', '.join(drivers)
+    if not options.nobanner:
+        print 'Database drivers available: %s' % ', '.join(drivers)
 
 
     # ## if -L load options from options.config file
     if options.config:
         try:
-            options2 = __import__(options.config, [], [], '')
+            options2 = __import__(options.config, {}, {}, '')
         except Exception:
             try:
                 # Jython doesn't like the extra stuff
-                options = __import__(options.config)
+                options2 = __import__(options.config)
             except Exception:
                 print 'Cannot import config file [%s]' % options.config
                 sys.exit(1)
@@ -880,16 +888,17 @@ def start(cron=True):
     if not root and options.password == '<ask>':
         options.password = raw_input('choose a password:')
 
-    if not options.password:
+    if not options.password and not options.nobanner:
         print 'no password, no admin interface'
 
     # ## start server
 
     (ip, port) = (options.ip, int(options.port))
 
-    print 'please visit:'
-    print '\thttp://%s:%s' % (ip, port)
-    print 'use "kill -SIGTERM %i" to shutdown the web2py server' % os.getpid()
+    if not options.nobanner:
+        print 'please visit:'
+        print '\thttp://%s:%s' % (ip, port)
+        print 'use "kill -SIGTERM %i" to shutdown the web2py server' % os.getpid()
 
     server = main.HttpServer(ip=ip,
                              port=port,
